@@ -1,9 +1,11 @@
+# ABSTRACT: Mojolicious plugin for integrating Disqus forum
+
 package Mojolicious::Plugin::Disqus::Tiny;
 
 use strictures 1;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '1.000';
 
 has 'template' => 'disqus_template';
 
@@ -77,6 +79,19 @@ L<Mojolicious::Plugin> and implements the following new ones.
 
 Register plugin in L<Mojolicious> application.
 
+=head1 AUTHOR
+
+Adam Stokes L<adamjs@cpan.org>
+
+=head1 COPYRIGHT
+
+Copyright 2013- Adam Stokes
+
+=head1 LICENSE
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 SEE ALSO
 
 L<Mojolicious::Plugin::Disqus>, L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
